import React from "react";
import { IntlShape } from "react-intl";
import { ITranslations } from "./messagesMap.js";
import { ILocale } from "./Locale.js";
/**
 * @internal
 */
export declare function createIntlMock(customMessages?: {}, locale?: string): IntlShape;
/**
 * @internal
 */
export declare function withIntlForTest<P>(WrappedComponent: React.FC<P> | React.ComponentClass<P>, customLocale?: ILocale, customMessages?: ITranslations): React.ComponentType<P>;
/**
 * @internal
 */
export declare function withIntl<P>(WrappedComponent: React.FC<P> | React.ComponentClass<P>, customLocale?: ILocale, customMessages?: ITranslations): React.ComponentType<P>;
/**
 * Resolves parameter into {@link ILocale} or {@link DefaultLocale}.
 *
 * @param locale - value of the locale to check for support
 *
 * @internal
 */
export declare const resolveLocale: (locale: unknown) => ILocale;
/**
 * This method try to resolve translations for the given locale.
 * If the locale is not found or is invalid, it will return the translations for default locale.
 * @param locale - input locale
 * @param messagesMap - map of messages
 * @returns resolved messages
 *
 * @internal
 */
export declare const resolveLocaleDefaultMessages: (locale: string, messagesMap: {
    [locale: string]: ITranslations;
}) => ITranslations;
/**
 * Returns a string meant to represent a header with an empty value.
 * @param intl - the source of i18n strings
 * @internal
 */
export declare function emptyHeaderTitleFromIntl(intl: IntlShape): string;
/**
 * Returns a string meant to represent the total colum when it is empty.
 * @param intl - the source of i18n strings
 * @internal
 */
export declare function totalColumnTitleFromIntl(intl: IntlShape): string;
/**
 * Returns a string meant to represent a cluster group.
 * @param intl - the source of i18n strings
 * @internal
 */
export declare function clusterTitleFromIntl(intl: IntlShape): string;
//# sourceMappingURL=intlUtils.d.ts.map